NZBackToTop class

NZBackToTop 当用户向下滚动时出现的按钮,允许用户快速滚动回顶部。

Inheritance

Constructors

NZBackToTop({Key? key, required ScrollController scrollController, double threshold = 300.0, Widget? child, Duration duration = const Duration(milliseconds: 500), Curve curve = Curves.easeInOut, EdgeInsets padding = const EdgeInsets.all(16.0)})
const

Properties

child Widget?
子组件 (通常是一个图标)
final
curve Curve
滚动动画的曲线
final
duration Duration
滚动动画的持续时间
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsets
距离屏幕边缘的内边距
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController
监听和控制的滚动控制器
final
threshold double
按钮出现前距离顶部的阈值距离
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NZBackToTop>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited