NZButtonStyle enum

NZButton 样式类型

Inheritance
Available extensions

Values

primary → const NZButtonStyle

主要按钮:有背景色,通常用于主操作

secondary → const NZButtonStyle

次要按钮:浅色背景,通常用于次要操作(类似微信小程序风格)

outline → const NZButtonStyle

描边按钮:无背景色,有边框

text → const NZButtonStyle

文字按钮:无背景色,无边框,仅显示文字或图标

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NZButtonStyle>
A constant List of the values in this enum, in order of their declaration.