NZImageButton class

NZImageButton 是一个带有背景图片的按钮。

Inheritance

Constructors

NZImageButton({Key? key, required ImageProvider<Object> image, VoidCallback? onPressed, Widget? child, String? label, double? width, double height = 180.0, double borderRadius = 12.0, bool block = false, double opacity = 0.8, Color? color, Color? foregroundColor})
const

Properties

block bool
final
borderRadius double
final
child Widget?
final
color Color?
按钮背景颜色 (如果不提供,则显示图片本身)
final
foregroundColor Color?
文本颜色 (默认为白色)
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
image ImageProvider<Object>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
onPressed VoidCallback?
final
opacity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited