NZCalendarStyle enum

NZCalendarStyle 样式类型

Inheritance
Available extensions

Values

classic → const NZCalendarStyle

经典样式:简洁明了,适合大多数场景

card → const NZCalendarStyle

卡片样式:带有阴影和边框,更具立体感

compact → const NZCalendarStyle

紧凑样式:单元格更小,适合空间有限的场景

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NZCalendarStyle>
A constant List of the values in this enum, in order of their declaration.