NZCodeTheme enum

代码查看器主题

Inheritance
Available extensions

Values

githubLight → const NZCodeTheme

GitHub Light 风格 (白色背景)

githubDark → const NZCodeTheme

GitHub Dark 风格 (深色背景)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NZCodeTheme>
A constant List of the values in this enum, in order of their declaration.