NZDialogAction class
NZDialog 动作按钮配置
Constructors
- NZDialogAction({required String label, VoidCallback? onPressed, bool isDestructive = false, bool isPrimary = false, Color? color})
-
const
Properties
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDestructive → bool
-
final
- isPrimary → bool
-
final
- label → String
-
final
- onPressed → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited