NZDialogType enum

NZDialog 类型

Inheritance
Available extensions

Values

basic → const NZDialogType

基础对话框

confirm → const NZDialogType

确认对话框

success → const NZDialogType

成功对话框

error → const NZDialogType

错误对话框

warning → const NZDialogType

警告对话框

info → const NZDialogType

信息对话框

input → const NZDialogType

输入对话框

loading → const NZDialogType

加载对话框

progress → const NZDialogType

进度对话框

image → const NZDialogType

图片/视觉对话框

status → const NZDialogType

状态展示对话框

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NZDialogType>
A constant List of the values in this enum, in order of their declaration.