NZDropDownMenuType enum
NZDropDownMenu 样式类型
Values
- outline → const NZDropDownMenuType
-
描边:有边框,通常用于常规表单
- filled → const NZDropDownMenuType
-
填充:有背景色,无边框
- borderless → const NZDropDownMenuType
-
无边框:纯文字样式,常用于导航栏
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NZDropDownMenuType> - A constant List of the values in this enum, in order of their declaration.