NZPopUpAction class

NZPopUp 动作按钮配置

Constructors

NZPopUpAction({required String label, VoidCallback? onPressed, bool isDestructive = false, bool isPrimary = false, Color? color})
const

Properties

color Color?
自定义颜色
final
hashCode int
The hash code for this object.
no setterinherited
isDestructive bool
是否为警示性操作(显示为红色)
final
isPrimary bool
是否为主操作(加粗显示)
final
label String
按钮文本
final
onPressed VoidCallback?
点击回调
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited