NZSwipeListTile class

滑动单元格组件 (类似微信小程序风格) 支持左右滑动展示操作按钮,支持长按

Inheritance

Constructors

NZSwipeListTile({Key? key, required Widget child, List<NZSwipeAction> leftActions = const [], List<NZSwipeAction> rightActions = const [], List<NZSwipeAction> topActions = const [], List<NZSwipeAction> bottomActions = const [], bool disabled = false, VoidCallback? onLongPress, VoidCallback? onTap, Color? backgroundColor})
const

Properties

backgroundColor Color?
背景颜色
final
bottomActions List<NZSwipeAction>
底部滑动出的按钮
final
child Widget
单元格主内容
final
disabled bool
是否禁用滑动
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftActions List<NZSwipeAction>
左侧滑动出的按钮
final
onLongPress VoidCallback?
长按回调
final
onTap VoidCallback?
点击回调
final
rightActions List<NZSwipeAction>
右侧滑动出的按钮
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topActions List<NZSwipeAction>
顶部滑动出的按钮
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NZSwipeListTile>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited