NZText class

NZText 具有预定义样式的排版组件集合。

Inheritance

Constructors

NZText(String data, {Key? key, TextStyle? style, TextAlign? textAlign, TextOverflow? overflow, int? maxLines})
const
NZText.body(String data, {Color? color, TextAlign? textAlign})
正文样式 (普通)
factory
NZText.caption(String data, {Color? color, TextAlign? textAlign})
说明文字样式 (小号)
factory
NZText.h1(String data, {Color? color, TextAlign? textAlign})
一级标题样式
factory
NZText.h2(String data, {Color? color, TextAlign? textAlign})
二级标题样式
factory
NZText.h3(String data, {Color? color, TextAlign? textAlign})
三级标题样式
factory
NZText.label(String data, {Color? color, TextAlign? textAlign})
标签文字样式 (中号加粗)
factory
NZText.subtitle(String data, {Color? color, TextAlign? textAlign})
副标题样式
factory

Properties

data String
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLines int?
final
overflow TextOverflow?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
final
textAlign TextAlign?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited