NZToastType enum
NZToast 类型枚举
Values
- success → const NZToastType
-
成功状态
- error → const NZToastType
-
错误状态
- loading → const NZToastType
-
加载中状态
- info → const NZToastType
-
信息提示状态
- text → const NZToastType
-
纯文本状态
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NZToastType> - A constant List of the values in this enum, in order of their declaration.