NZDatabase class

Constructors

NZDatabase.init()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required String databaseName, required List<NZORMEngine> tables, int? version = 1}) Future<void>
createTable({required Database db, required NZORMEngine table}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NZDatabase
no setter