NZColor class
NZColor 类定义了应用程序使用的所有核心色彩方案 包含 10 个色阶的 Material Design 标准调色板
Constructors
- NZColor()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- amber50 → const Color
- amber100 → const Color
- amber200 → const Color
- amber300 → const Color
- amber400 → const Color
- amber500 → const Color
- amber600 → const Color
- amber700 → const Color
- amber800 → const Color
- amber900 → const Color
- blue50 → const Color
- blue100 → const Color
- blue200 → const Color
- blue300 → const Color
- blue400 → const Color
- blue500 → const Color
- blue600 → const Color
- blue700 → const Color
- blue800 → const Color
- blue900 → const Color
- blueGrey50 → const Color
- blueGrey100 → const Color
- blueGrey200 → const Color
- blueGrey300 → const Color
- blueGrey400 → const Color
- blueGrey500 → const Color
- blueGrey600 → const Color
- blueGrey700 → const Color
- blueGrey800 → const Color
- blueGrey900 → const Color
- brown50 → const Color
- brown100 → const Color
- brown200 → const Color
- brown300 → const Color
- brown400 → const Color
- brown500 → const Color
- brown600 → const Color
- brown700 → const Color
- brown800 → const Color
- brown900 → const Color
- cyan50 → const Color
- cyan100 → const Color
- cyan200 → const Color
- cyan300 → const Color
- cyan400 → const Color
- cyan500 → const Color
- cyan600 → const Color
- cyan700 → const Color
- cyan800 → const Color
- cyan900 → const Color
- deepOrange50 → const Color
- deepOrange100 → const Color
- deepOrange200 → const Color
- deepOrange300 → const Color
- deepOrange400 → const Color
- deepOrange500 → const Color
- deepOrange600 → const Color
- deepOrange700 → const Color
- deepOrange800 → const Color
- deepOrange900 → const Color
- deepPurple50 → const Color
- deepPurple100 → const Color
- deepPurple200 → const Color
- deepPurple300 → const Color
- deepPurple400 → const Color
- deepPurple500 → const Color
- deepPurple600 → const Color
- deepPurple700 → const Color
- deepPurple800 → const Color
- deepPurple900 → const Color
- green50 → const Color
- green100 → const Color
- green200 → const Color
- green300 → const Color
- green400 → const Color
- green500 → const Color
- green600 → const Color
- green700 → const Color
- green800 → const Color
- green900 → const Color
- grey50 → const Color
- grey100 → const Color
- grey200 → const Color
- grey300 → const Color
- grey400 → const Color
- grey500 → const Color
- grey600 → const Color
- grey700 → const Color
- grey800 → const Color
- grey900 → const Color
- indigo50 → const Color
- indigo100 → const Color
- indigo200 → const Color
- indigo300 → const Color
- indigo400 → const Color
- indigo500 → const Color
- indigo600 → const Color
- indigo700 → const Color
- indigo800 → const Color
- indigo900 → const Color
- lightBlue50 → const Color
- lightBlue100 → const Color
- lightBlue200 → const Color
- lightBlue300 → const Color
- lightBlue400 → const Color
- lightBlue500 → const Color
- lightBlue600 → const Color
- lightBlue700 → const Color
- lightBlue800 → const Color
- lightBlue900 → const Color
- lightGreen50 → const Color
- lightGreen100 → const Color
- lightGreen200 → const Color
- lightGreen300 → const Color
- lightGreen400 → const Color
- lightGreen500 → const Color
- lightGreen600 → const Color
- lightGreen700 → const Color
- lightGreen800 → const Color
- lightGreen900 → const Color
- lime50 → const Color
- lime100 → const Color
- lime200 → const Color
- lime300 → const Color
- lime400 → const Color
- lime500 → const Color
- lime600 → const Color
- lime700 → const Color
- lime800 → const Color
- lime900 → const Color
- nezhaBlue → const Color
- nezhaCyan → const Color
- nezhaGreen → const Color
- nezhaIndigo → const Color
- nezhaOrange → const Color
- nezhaPink → const Color
- nezhaPrimary → const Color
- 应用程序主色调,默认为标准红色
- nezhaPurple → const Color
- nezhaRed → const Color
- 常用语义色彩快捷访问
- nezhaSecondary → const Color
- 应用程序辅助色调,默认为标准橙色
- nezhaSub → const Color
- 应用程序次要辅助色,默认为标准黄色
- nezhaTeal → const Color
- nezhaYellow → const Color
- orange50 → const Color
- orange100 → const Color
- orange200 → const Color
- orange300 → const Color
- orange400 → const Color
- orange500 → const Color
- orange600 → const Color
- orange700 → const Color
- orange800 → const Color
- orange900 → const Color
- pink50 → const Color
- pink100 → const Color
- pink200 → const Color
- pink300 → const Color
- pink400 → const Color
- pink500 → const Color
- pink600 → const Color
- pink700 → const Color
- pink800 → const Color
- pink900 → const Color
- purple50 → const Color
- purple100 → const Color
- purple200 → const Color
- purple300 → const Color
- purple400 → const Color
- purple500 → const Color
- purple600 → const Color
- purple700 → const Color
- purple800 → const Color
- purple900 → const Color
- red50 → const Color
- red100 → const Color
- red200 → const Color
- red300 → const Color
- red400 → const Color
- red500 → const Color
- red600 → const Color
- red700 → const Color
- red800 → const Color
- red900 → const Color
- teal50 → const Color
- teal100 → const Color
- teal200 → const Color
- teal300 → const Color
- teal400 → const Color
- teal500 → const Color
- teal600 → const Color
- teal700 → const Color
- teal800 → const Color
- teal900 → const Color
- yellow50 → const Color
- yellow100 → const Color
- yellow200 → const Color
- yellow300 → const Color
- yellow400 → const Color
- yellow500 → const Color
- yellow600 → const Color
- yellow700 → const Color
- yellow800 → const Color
- yellow900 → const Color