NZDialog class
NZDialog 是一个多功能的对话框组件,支持 10 种以上不同的样式。
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- NZDialog
Constructors
Properties
-
actions
→ List<
NZDialogAction> ? -
final
- barrierDismissible → bool
-
final
- content → Widget?
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
final
- iconColor → Color?
-
final
- imagePath → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- message → String?
-
final
- progressValue → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
- type → NZDialogType
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
alert(
BuildContext context, String message, {String title = '提示'}) → Future< void> -
confirm(
BuildContext context, String message, {String title = '确认操作', String confirmLabel = '确定', String cancelLabel = '取消'}) → Future< bool?> -
- 确认对话框
-
error(
BuildContext context, String message, {String title = '出错了'}) → Future< void> -
image(
BuildContext context, String imageUrl, {String? title, String? message}) → Future< void> -
info(
BuildContext context, String message, {String title = '详情'}) → Future< void> - 信息对话框
-
input(
BuildContext context, {String title = '输入内容', String? hintText, String confirmLabel = '提交', String? initialValue}) → Future< String?> -
- 输入对话框
-
loading(
BuildContext context, {String message = '加载中...'}) → Future< void> -
progress(
BuildContext context, double value, {String title = '正在同步数据'}) → Future< void> - 进度对话框
-
show<
T> (BuildContext context, {String? title, String? message, Widget? content, List< NZDialogAction> ? actions, NZDialogType type = NZDialogType.basic, IconData? icon, Color? iconColor, double? progress, String? imagePath, bool barrierDismissible = true, }) → Future<T?> - 快速显示对话框
-
status(
BuildContext context, {required String title, required String message, required Widget statusWidget}) → Future< void> -
- 状态展示对话框
-
success(
BuildContext context, String message, {String title = '成功'}) → Future< void> -
- 成功对话框
-
warning(
BuildContext context, String message, {String title = '安全警告'}) → Future< void> - 警告对话框