NZMarkdown class
NZMarkdown 是一个轻量级的 Markdown 渲染组件,完全使用 Flutter 原生组件实现。
此组件不依赖任何第三方 Markdown 库,支持以下语法:
- 标题 (#, ##, ###)
- 加粗 (text)
- 斜体 (text)
- 行内代码 (
code) - 代码块 (
code) - 引用 (> quote)
- 无序列表 (- 或 *)
- 分割线 (--- 或 ***)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- NZMarkdown
Constructors
- NZMarkdown({Key? key, required String data, NZMarkdownStyle? style})
-
创建一个 NZMarkdown 组件。
const
Properties
- data → String
-
需要渲染的 Markdown 原始文本数据。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → NZMarkdownStyle?
-
Markdown 的样式配置。如果为 null,将使用默认样式。
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited