NZNavBarType enum
NZNavBar 的展现类型
Values
- normal → const NZNavBarType
-
标准模式:包含标题、返回按钮和操作按钮
- search → const NZNavBarType
-
搜索模式:点击搜索图标可展开搜索框
- logo → const NZNavBarType
-
Logo 模式:左侧显示 Logo 和品牌名称
- miniApp → const NZNavBarType
-
小程序模式:右侧显示类似微信小程序的“胶囊”控制按钮
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NZNavBarType> - A constant List of the values in this enum, in order of their declaration.