NZSwipeAction class
滑动操作按钮配置
Constructors
- NZSwipeAction({String? label, Widget? icon, Color? backgroundColor, VoidCallback? onTap, double width = 80.0, double height = 80.0})
-
const
Properties
- backgroundColor → Color?
-
背景颜色
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
按钮高度,默认 80.0
final
- icon → Widget?
-
按钮图标
final
- label → String?
-
按钮标签
final
- onTap → VoidCallback?
-
点击回调
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
按钮宽度,默认 80.0
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited