NZTheme class

NZTheme 类提供了 NezhaUI 的主题配置管理。

它可以根据 NZThemeConfig 生成符合 Material Design 规范的 ThemeData

Constructors

NZTheme()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

darkTheme([NZThemeConfig config = NZThemeConfig.defaultContent]) ThemeData
获取深色主题配置
lightTheme([NZThemeConfig config = NZThemeConfig.defaultContent]) ThemeData
获取浅色主题配置