NZThemeConfig class

NZThemeConfig 允许开发者自定义 NezhaUI 的外观和感觉。

通过配置主色调、圆角半径和字体等参数,可以轻松实现个性化定制。

Constructors

NZThemeConfig({Color primaryColor = NZColor.nezhaPrimary, Color secondaryColor = NZColor.nezhaSecondary, double borderRadius = 12.0, Color lightScaffoldBackgroundColor = const Color(0xFFF8F9FA), Color darkScaffoldBackgroundColor = const Color(0xFF121212), String? fontFamily})
const

Properties

borderRadius double
全局圆角半径
final
darkScaffoldBackgroundColor Color
页面背景颜色 (深色)
final
fontFamily String?
默认字体族
final
hashCode int
The hash code for this object.
no setterinherited
lightScaffoldBackgroundColor Color
页面背景颜色 (浅色)
final
primaryColor Color
主色调
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor Color
次色调
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultContent → const NZThemeConfig
默认配置